summaryrefslogtreecommitdiffstats
path: root/runtime/src/program.rs
diff options
context:
space:
mode:
Diffstat (limited to 'runtime/src/program.rs')
-rw-r--r--runtime/src/program.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/runtime/src/program.rs b/runtime/src/program.rs
index 0ea94d3b..77acf497 100644
--- a/runtime/src/program.rs
+++ b/runtime/src/program.rs
@@ -1,5 +1,5 @@
//! Build interactive programs using The Elm Architecture.
-use crate::Command;
+use crate::Task;
use iced_core::text;
use iced_core::Element;
@@ -25,9 +25,9 @@ pub trait Program: Sized {
/// produced by either user interactions or commands, will be handled by
/// this method.
///
/// Any [`Command`] returned will be executed immediately in the
/// background by shells.
- fn update(&mut self, message: Self::Message) -> Command<Self::Message>;
+ fn update(&mut self, message: Self::Message) -> Task<Self::Message>;
/// Returns the widgets to display in the [`Program`].
///
@@ -25,9 +25,9 @@ pub trait Program: Sized {
/// this method.
///
- /// Any [`Command`] returned will be executed immediately in the
+ /// Any [`Task`] returned will be executed immediately in the
/// background by shells.